event_msg

Function event_msg 

pub fn event_msg(event: Evt, parent: Option<Id>) -> EventMsg
event stamped with a fresh event id and the current time, correlated to the op it answers (parent), if any.