pub struct ModelSpec {Show 13 fields
pub id: String,
pub display_name: Option<String>,
pub description: Option<String>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub top_k: Option<u32>,
pub max_tokens: Option<u32>,
pub stop_sequences: Option<Vec<String>>,
pub context_limit: Option<u32>,
pub effort: Option<Effort>,
pub supported_efforts: Option<Vec<Effort>>,
pub support_vision: Option<bool>,
pub weight_class: Option<WeightClass>,
}Fields
id: Stringdisplay_name: Option<String>description: Option<String>temperature: Option<f32>top_p: Option<f32>top_k: Option<u32>max_tokens: Option<u32>stop_sequences: Option<Vec<String>>context_limit: Option<u32>effort: Option<Effort>supported_efforts: Option<Vec<Effort>>The effort levels this model supports when configured in the user catalog. When absent, the provider’s built-in model profile supplies the ladder; an empty list means that the model takes no effort setting.
support_vision: Option<bool>weight_class: Option<WeightClass>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ModelSpec
impl<'de> Deserialize<'de> for ModelSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for ModelSpec